/*
Copyright © 2021 da/net research group <danet.fbi.h-da.de>
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors
   may be used to endorse or promote products derived from this software
   without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*/

package cmd

import (
	"github.com/google/uuid"
	"github.com/pterm/pterm"
	"github.com/spf13/cobra"
)

// confirmCmd represents the confirm command.
var confirmCmd = &cobra.Command{
	Use:   "confirm [uuid]",
	Args:  cobra.ExactArgs(1),
	Short: "confirms the given change for the currently selected PND",
	Long: `Confirms the given confiduration change for the currently selected PND.
Change UUID must be specified as positional argument`,

	Run: func(cmd *cobra.Command, args []string) {
		cuid, err := uuid.Parse(args[0])
		if err != nil {
			pterm.Error.Println(err)
			return
		}

		resp, err := pndAdapter.Confirm(createContextWithAuthorization(), cuid)
		if err != nil {
			pterm.Error.Println(err)
			return
		}
		for _, r := range resp.GetResponses() {
			pterm.Info.Printfln("Change with ID: %s has been confirmed.", r.GetId())
		}
	},
}

func init() {
	changeCmd.AddCommand(confirmCmd)
}
